Introduction
============

plone.app.jquery adds `jquery`_ library to Plone.

Versions
========

Version numbers of the package is the same as the jQuery library + packaging version.

Available versions of this package are:

- 1.8.3
- 1.7.2
- 1.4.4

jQuery 1.7 is not supported on Plone < 4.3. So if you have dependencies on plone.app.jquery
you should pin it in your buildout configuration to 1.4.4.

.. _`jquery`: http://jquery.com
